import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import {
  GraduationCap,
  FileText,
  Search,
  Users,
  Clock,
  CheckCircle,
  ArrowRight,
  Shield,
  Microscope,
  Calculator,
  Briefcase,
  Heart,
  Scale,
  Target,
} from "lucide-react"

export default function ServicesPage() {
  const services = [
    {
      category: "Research & Analysis",
      icon: <Microscope className="h-8 w-8" />,
      color: "from-blue-600 to-blue-700",
      services: [
        {
          name: "Research Papers",
          description: "Comprehensive academic research with proper citations",
          price: "From $25/page",
        },
        { name: "Literature Reviews", description: "Systematic analysis of existing research", price: "From $30/page" },
        { name: "Case Studies", description: "In-depth analysis of real-world scenarios", price: "From $28/page" },
        { name: "Data Analysis", description: "Statistical analysis and interpretation", price: "From $35/page" },
      ],
    },
    {
      category: "Academic Writing",
      icon: <FileText className="h-8 w-8" />,
      color: "from-emerald-600 to-emerald-700",
      services: [
        {
          name: "Essays & Papers",
          description: "High-quality academic essays across all subjects",
          price: "From $20/page",
        },
        {
          name: "Thesis & Dissertations",
          description: "Comprehensive graduate-level research",
          price: "From $45/page",
        },
        { name: "Term Papers", description: "Detailed semester-end academic papers", price: "From $25/page" },
        { name: "Book Reports", description: "Analytical reviews of literary works", price: "From $18/page" },
      ],
    },
    {
      category: "Business & Economics",
      icon: <Briefcase className="h-8 w-8" />,
      color: "from-amber-600 to-amber-700",
      services: [
        { name: "Business Plans", description: "Comprehensive business strategy documents", price: "From $40/page" },
        { name: "Market Analysis", description: "Industry and market research reports", price: "From $35/page" },
        { name: "Financial Analysis", description: "Corporate financial evaluation", price: "From $38/page" },
        { name: "SWOT Analysis", description: "Strategic business assessment", price: "From $30/page" },
      ],
    },
    {
      category: "STEM Fields",
      icon: <Calculator className="h-8 w-8" />,
      color: "from-purple-600 to-purple-700",
      services: [
        { name: "Lab Reports", description: "Scientific experiment documentation", price: "From $22/page" },
        { name: "Technical Papers", description: "Engineering and technology research", price: "From $32/page" },
        { name: "Mathematical Proofs", description: "Complex mathematical demonstrations", price: "From $35/page" },
        { name: "Scientific Reviews", description: "Peer review of scientific literature", price: "From $30/page" },
      ],
    },
    {
      category: "Healthcare & Medicine",
      icon: <Heart className="h-8 w-8" />,
      color: "from-red-600 to-red-700",
      services: [
        { name: "Medical Research", description: "Clinical and medical research papers", price: "From $40/page" },
        { name: "Nursing Papers", description: "Healthcare and nursing studies", price: "From $28/page" },
        { name: "Public Health", description: "Community health research", price: "From $32/page" },
        { name: "Pharmacology", description: "Drug research and analysis", price: "From $35/page" },
      ],
    },
    {
      category: "Legal Studies",
      icon: <Scale className="h-8 w-8" />,
      color: "from-slate-600 to-slate-700",
      services: [
        { name: "Legal Briefs", description: "Comprehensive legal document analysis", price: "From $38/page" },
        { name: "Case Analysis", description: "Detailed legal case examination", price: "From $35/page" },
        { name: "Constitutional Law", description: "Constitutional legal research", price: "From $40/page" },
        { name: "Contract Analysis", description: "Legal contract evaluation", price: "From $32/page" },
      ],
    },
  ]

  const features = [
    {
      icon: <Users className="h-6 w-6" />,
      title: "Expert Writers",
      description: "PhD-qualified professionals in every field",
    },
    {
      icon: <Clock className="h-6 w-6" />,
      title: "Timely Delivery",
      description: "Always delivered on or before deadline",
    },
    {
      icon: <Shield className="h-6 w-6" />,
      title: "100% Original",
      description: "Plagiarism-free, custom-written content",
    },
    {
      icon: <Target className="h-6 w-6" />,
      title: "Quality Guarantee",
      description: "Unlimited revisions until satisfied",
    },
  ]

  return (
    <div className="min-h-screen">
      {/* Header */}
      <header className="header-academic">
        <div className="container-academic">
          <div className="flex justify-between items-center py-4">
            <Link href="/" className="flex items-center">
              <div className="w-12 h-12 bg-navy rounded-lg flex items-center justify-center book-spine">
                <GraduationCap className="h-7 w-7 text-white" />
              </div>
              <span className="ml-3 text-2xl font-bold text-navy font-merriweather">ProEssayWorks</span>
            </Link>
            <nav className="hidden md:flex space-x-8">
              <Link href="/" className="nav-academic">
                Home
              </Link>
              <Link href="/services" className="nav-academic nav-academic-active">
                Services
              </Link>
              <Link href="/how-it-works" className="nav-academic">
                How It Works
              </Link>
              <Link href="/pricing" className="nav-academic">
                Pricing
              </Link>
              <Link href="/about" className="nav-academic">
                About
              </Link>
            </nav>
            <div className="flex space-x-3">
              <Link href="/auth/login">
                <Button variant="ghost" className="nav-academic font-medium">
                  Sign In
                </Button>
              </Link>
              <Link href="/auth/register">
                <Button className="btn-academic-primary">Get Started</Button>
              </Link>
            </div>
          </div>
        </div>
      </header>

      {/* Hero Section */}
      <section className="hero-academic section-academic-large">
        <div className="container-academic text-center text-white">
          <div className="max-w-4xl mx-auto space-y-8">
            <h1 className="heading-academic-primary text-white">
              Comprehensive Academic Services
              <span className="block bg-gradient-to-r from-yellow-300 to-amber-300 bg-clip-text text-transparent mt-2">
                Excellence Across All Disciplines
              </span>
            </h1>
            <p className="body-academic-large text-white/90">
              From research papers to dissertations, our expert writers deliver exceptional academic content across
              every field of study with unmatched quality and precision.
            </p>
            <div className="flex flex-col sm:flex-row gap-4 justify-center max-w-lg mx-auto">
              <Link href="/auth/register?role=client">
                <Button className="btn-academic-secondary text-base px-8 py-4 w-full sm:w-auto">
                  Start Your Project
                  <ArrowRight className="ml-2 h-5 w-5" />
                </Button>
              </Link>
              <Link href="/pricing">
                <Button
                  variant="outline"
                  className="text-base px-8 py-4 w-full sm:w-auto text-white border-white hover:bg-white hover:text-navy"
                >
                  View Pricing
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Features Section */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="grid md:grid-cols-4 gap-8">
            {features.map((feature, index) => (
              <div key={index} className="text-center">
                <div className="w-16 h-16 bg-gradient-to-br from-navy to-navy-light rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  {feature.icon}
                </div>
                <h3 className="text-xl font-bold mb-3 text-navy font-merriweather">{feature.title}</h3>
                <p className="body-academic-regular text-gray-cool">{feature.description}</p>
              </div>
            ))}
          </div>
        </div>
      </section>

      {/* Services Grid */}
      <section className="section-academic-large paper-texture">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Our Academic Services</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Comprehensive writing services across all academic disciplines, delivered by subject matter experts with
              advanced degrees and extensive research experience.
            </p>
          </div>

          <div className="grid lg:grid-cols-2 gap-12">
            {services.map((category, index) => (
              <Card key={index} className="card-academic">
                <CardHeader>
                  <div className="flex items-center mb-4">
                    <div
                      className={`w-12 h-12 bg-gradient-to-br ${category.color} rounded-lg flex items-center justify-center text-white mr-4`}
                    >
                      {category.icon}
                    </div>
                    <CardTitle className="heading-academic-tertiary">{category.category}</CardTitle>
                  </div>
                </CardHeader>
                <CardContent>
                  <div className="space-y-4">
                    {category.services.map((service, serviceIndex) => (
                      <div key={serviceIndex} className="border-l-4 border-navy/20 pl-4 py-2">
                        <div className="flex justify-between items-start mb-2">
                          <h4 className="font-semibold text-navy">{service.name}</h4>
                          <Badge variant="outline" className="text-navy border-navy">
                            {service.price}
                          </Badge>
                        </div>
                        <p className="body-academic-small text-gray-cool">{service.description}</p>
                      </div>
                    ))}
                  </div>
                  <div className="mt-6 pt-4 border-t">
                    <Link href="/auth/register?role=client">
                      <Button className="w-full btn-academic-primary">
                        Order {category.category}
                        <ArrowRight className="ml-2 h-4 w-4" />
                      </Button>
                    </Link>
                  </div>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Quality Assurance */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Quality Assurance Process</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Every project undergoes our rigorous quality control process to ensure academic excellence and
              originality.
            </p>
          </div>

          <div className="grid md:grid-cols-3 gap-8">
            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-blue-600 to-blue-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <Search className="h-8 w-8" />
                </div>
                <CardTitle className="heading-academic-tertiary">Research & Planning</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular">
                  Comprehensive research using academic databases and peer-reviewed sources to ensure factual accuracy
                  and depth.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-emerald-600 to-emerald-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <FileText className="h-8 w-8" />
                </div>
                <CardTitle className="heading-academic-tertiary">Expert Writing</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular">
                  Subject matter experts craft your content with proper academic structure, citations, and scholarly
                  tone.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-amber-600 to-amber-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <CheckCircle className="h-8 w-8" />
                </div>
                <CardTitle className="heading-academic-tertiary">Quality Review</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular">
                  Multi-stage editing, proofreading, and plagiarism checking to guarantee originality and excellence.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="section-academic hero-academic">
        <div className="container-academic text-center text-white">
          <div className="max-w-4xl mx-auto space-y-8">
            <h2 className="heading-academic-secondary text-white">Ready to Excel in Your Studies?</h2>
            <p className="body-academic-large text-white/90">
              Join thousands of students who have achieved academic success with our professional writing services.
            </p>
            <div className="flex flex-col sm:flex-row gap-6 justify-center max-w-lg mx-auto">
              <Link href="/auth/register?role=client">
                <Button className="btn-academic-secondary text-base px-8 py-4 w-full sm:w-auto">
                  Get Started Today
                  <ArrowRight className="ml-2 h-5 w-5" />
                </Button>
              </Link>
              <Link href="/pricing">
                <Button
                  variant="outline"
                  className="text-base px-8 py-4 w-full sm:w-auto text-white border-white hover:bg-white hover:text-navy"
                >
                  View Pricing Plans
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-navy text-white section-academic">
        <div className="container-academic">
          <div className="grid md:grid-cols-4 gap-10">
            <div className="space-y-8">
              <div className="flex items-center">
                <div className="w-12 h-12 bg-navy-light rounded-lg flex items-center justify-center book-spine">
                  <GraduationCap className="h-7 w-7 text-white" />
                </div>
                <span className="ml-3 text-2xl font-bold font-merriweather">ProEssayWorks</span>
              </div>
              <p className="body-academic-regular text-white/80">
                Empowering academic excellence through distinguished scholarship and expert writing services.
              </p>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Quick Links</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li>
                  <Link href="/" className="hover:text-white transition-colors">
                    Home
                  </Link>
                </li>
                <li>
                  <Link href="/services" className="hover:text-white transition-colors">
                    Services
                  </Link>
                </li>
                <li>
                  <Link href="/how-it-works" className="hover:text-white transition-colors">
                    How It Works
                  </Link>
                </li>
                <li>
                  <Link href="/pricing" className="hover:text-white transition-colors">
                    Pricing
                  </Link>
                </li>
                <li>
                  <Link href="/about" className="hover:text-white transition-colors">
                    About
                  </Link>
                </li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Services</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li className="hover:text-white transition-colors cursor-pointer">Research Papers</li>
                <li className="hover:text-white transition-colors cursor-pointer">Essays</li>
                <li className="hover:text-white transition-colors cursor-pointer">Dissertations</li>
                <li className="hover:text-white transition-colors cursor-pointer">Case Studies</li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Support</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li className="hover:text-white transition-colors cursor-pointer">Contact Us</li>
                <li className="hover:text-white transition-colors cursor-pointer">FAQ</li>
                <li className="hover:text-white transition-colors cursor-pointer">Privacy Policy</li>
                <li className="hover:text-white transition-colors cursor-pointer">Terms of Service</li>
              </ul>
            </div>
          </div>
          <div className="border-t border-navy-light mt-16 pt-10 text-center">
            <p className="body-academic-regular text-white/70">&copy; 2024 ProEssayWorks. All rights reserved.</p>
          </div>
        </div>
      </footer>
    </div>
  )
}
